#!/bin/bash

set -o errexit
set -o verbose

if [ $# != 2 ]; then
    echo "USAGE: configure-common.sh [MASTER-IP] [CLUSTER-MEMBERS]"
    echo ""
    echo "CLUSTER-MEMBERS ex: \"172.18.4.100[7600],172.18.4.101[7600]\""
    exit 1
fi

MASTER_IP="$1"
NODES="$2"

# Bind to the IP that we can route to MASTER_IP through
BIND_IP=$(ruby -e "require 'asm'; puts ASM::Util.get_preferred_ip('$MASTER_IP')")

TORQUEBOX_DIR=/opt/jruby-1.7.8/lib/ruby/gems/shared/gems/torquebox-server-3.0.2-java/jboss/standalone

# Set up razor for clustering
if ! grep '\-\-clustered' /etc/init.d/razor; then
    sed -i -e "s/BIND_ADDRESS=[0-9.]*/BIND_ADDRESS=$BIND_IP/" /etc/sysconfig/razor
    sed -i -e "s/torquebox run --bind-address/torquebox run --clustered --bind-address/" /etc/init.d/razor

    puppet apply -e "asm::razor_cluster { \"cluster\" : members => \"$NODES\" }"
fi
