#!/bin/bash

set -o errexit
set -o verbose

if [ $# != 2 ]; then
    echo "USAGE: configure-master.sh [MASTER-IP] [CLUSTER-MEMBERS]"
    echo ""
    echo "CLUSTER-MEMBERS ex: \"172.18.4.100[7600],172.18.4.101[7600]\""
    exit 1
fi

MASTER_IP="$1"
NODES="$2"

./configure-common.sh "$MASTER_IP"
./configure-cluster.sh "$MASTER_IP" "$NODES"

# Set work_method to :queue
sed -i -e "s/work_method: [:a-zA-Z_]*/work_method: :queue/" /opt/asm-deployer/config.yaml

# Set concurrency to zero (no jobs run on master)
sed -i -e "s/concurrency [0-9]*/concurrency 0/" /opt/asm-deployer/torquebox.rb

# Wait for asm-deployer to be online if needed
while ! curl -f http://asm-deployer-api:8081/asm/status; do
    echo Waiting for asm-deployer to become available...
    sleep 5
done

# torquebox deploy the changes
cd /opt/asm-deployer
torquebox deploy

# Wait for asm-deployer to be online if needed
sleep 5
while ! curl -f http://asm-deployer-api:8081/asm/status; do
    echo Waiting for asm-deployer to become available...
    sleep 5
done

# Disable nagios
chkconfig nagios off
service nagios stop

# Comment all lines in nagios cron
sed -i -e 's/^\([^#].*\)$/# \1/' /etc/cron.d/asm_nagios
