#!/bin/bash

set -o errexit
set -o verbose

if [ $# != 1 ]; then
    echo "USAGE: configure-nagios.sh [MASTER-IP]"
    echo ""
    echo "IMPORTANT: /opt/Dell/ssl/ca-cert.pem, dellasm.cert and dellasm_u.key"
    echo "must be copied from the master appliance onto the same location on"
    echo "this node."
    exit 1
fi

MASTER_IP="$1"

./configure-common.sh "$MASTER_IP"

# Set secrets_source to :rest
sed -i -e "s/secrets_source: [:a-zA-Z_]*/secrets_source: :rest/" /opt/asm-deployer/config.yaml

# Check that ASM::Razor is working
if ! ruby -e 'require "asm"; puts ASM::Razor.new.get("repos").to_yaml'; then
    echo "Could not connect to razor service. Were ca-cert.pem, dellasm.cert,"
    echo "and dellasm_u.key copied into /opt/Dell/ssl?"
fi

# Check that ASM.secrets is working
if ! ruby -e 'require "asm"; ASM.secrets.api_auth'; then
    echo "Could not retrieve API auth. Were ca-cert.pem, dellasm.cert,"
    echo "and dellasm_u.key copied into /opt/Dell/ssl?"
fi

# Disable unnecessary services
for i in asmdb httpd pe-httpd pe-mcollective pe-puppet pe-puppetdb tog-pegasus tomeeASM carbon-cache razor
do
  chkconfig $i off
  service $i stop
done
