#!/bin/bash

set -o errexit
set -o verbose

if [ $# != 2 ]; then
    echo "USAGE: configure-worker.sh [MASTER-IP] [CLUSTER-MEMBERS]"
    echo ""
    echo "CLUSTER-MEMBERS ex: \"172.18.4.100[7600],172.18.4.101[7600]\""
    echo "IMPORTANT: /opt/Dell/ssl/ca-cert.pem ,dellasm_jgroup.jceks, dellasm.cert and dellasm_u.key"
    echo "must be copied from the master appliance onto the same location on"
    echo "this node."
    exit 1
fi

MASTER_IP="$1"
NODES="$2"

./configure-common.sh "$MASTER_IP"
#Need to rebuild java keystore and import with new dellasmcert
pushd /opt/Dell/ssl/
rm dellasm.jks dellasm.p12
/usr/bin/expect <<EOF
spawn /usr/bin/openssl pkcs12 -export -in dellasm.cert -inkey dellasm_u.key  -out dellasm.p12 -name dellasm_tomcat -CAfile ca-cert.pem -caname dellasm -chain
expect -exact "Enter Export Password:"
send -- "Dell@123$\r"
expect -exact "Verifying - Enter Export Password:"
send -- "Dell@123$\r"
expect eof
spawn /opt/puppet/bin/keytool -importkeystore -srckeystore dellasm.p12 -srcstoretype pkcs12 -srcalias dellasm_tomcat -destkeystore dellasm.jks -deststoretype jks -destalias dellasm
expect -exact "Enter destination keystore password:"
send -- "Dell@123$\r"
expect -exact "Re-enter new password:"
send -- "Dell@123$\r"
expect -exact "Enter source keystore password:"
send -- "Dell@123$\r"
expect eof
spawn /opt/puppet/bin/keytool -import -noprompt -trustcacerts -alias dellasm_tomcat -file /opt/Dell/ssl/dellasm.cert -keystore /opt/java/jre/lib/security/cacerts
expect -exact "Enter keystore password:"
send -- "changeit\r"
expect eof
EOF
popd

./configure-cluster.sh "$MASTER_IP" "$NODES"


# Set secrets_source to :rest
sed -i -e "s/secrets_source: [:a-zA-Z_]*/secrets_source: :rest/" /opt/asm-deployer/config.yaml

# Set concurrency to 10
sed -i -e "s/concurrency [0-9]*/concurrency 10/" /opt/asm-deployer/torquebox.rb

sleep 15

# torquebox deploy the changes
cd /opt/asm-deployer
torquebox deploy

# Wait for asm-deployer to be online if needed
sleep 15

# Check that ASM::Razor is working
if ! ruby -e 'require "asm"; puts ASM::Razor.new.get("repos").to_yaml'; then
    echo "Could not connect to razor service. Were ca-cert.pem, dellasm.cert,"
    echo "and dellasm_u.key copied into /opt/Dell/ssl?"
fi

# Check that ASM.secrets is working
if ! ruby -e 'require "asm"; ASM.secrets.api_auth'; then
    echo "Could not retrieve API auth. Were ca-cert.pem, dellasm.cert,"
    echo "and dellasm_u.key copied into /opt/Dell/ssl?"
fi

# Comment all lines in nagios cron
sed -i -e 's/^\([^#].*\)$/# \1/' /etc/cron.d/asm_nagios

# Disable unnecessary services
for i in asmdb httpd nagios pe-httpd pe-mcollective pe-puppet pe-puppetdb tog-pegasus tomeeASM carbon-cache
do
  chkconfig $i off
  service $i stop
done
