###########################################################################
#    Copyright (c) 2003-2013 Dell Inc. All rights reserved.               *
#                                                                         *
#  DELL INC. CONFIDENTIAL AND PROPRIETARY INFORMATION. This software may  *
#  only be supplied under the terms of a license agreement or             *
#  nondisclosure agreement with Dell Inc. and may not be copied or        *
#  disclosed except in accordance with the terms of such agreement.       *
###########################################################################

use strict;
use FindBin;
use lib "$FindBin::Bin/../";

use VMware::VIRuntime;
use VMware::VILib;
use AppUtil::HostUtil;
use AppUtil::VMUtil;
use Data::Dumper;

$Util::script_version = "1.0";

my %opts = (
    vmName => {
        type => "=s",
        help => "Name of the VM",
        required => 1
    },
    getDataStore => {
        type => "=s",
        help => "Yes or No",
        required => 0
    },
    datacenter => {
        type => "=s",
        help => "Datacenter name",
        required => 1
    }
);

Opts::add_options(%opts);
Opts::parse();
Opts::validate();

my @myArray;
my @networkArray;
eval
{
    Util::connect();
};
if ($@)
{
    print "Error: ".$@."\n";
    exit;
}

my $vm_name = Opts::get_option('vmName');
my $getDataStore = Opts::get_option('getDataStore');
my $datacenter = Opts::get_option('datacenter');

if ( defined $vm_name )
{
    #my @myArray1=getVMInfo();
    #print "myArray1=@myArray1\n"
    getVMInfo();
}

Util::disconnect();

sub getVMInfo
{
    eval
        {
        my $dc_view = Vim::find_entity_view ( view_type => "Datacenter", filter => { name => $datacenter }, properties => [ 'name' ] );
        die "No Datacenter named '$datacenter' found!" unless $dc_view;
        my $vmInfo = Vim::find_entity_view( view_type => 'VirtualMachine', begin_entity => $dc_view , filter => {'name' => $vm_name});

        #print ("VM INFO ".Dumper($vmInfo)."\n");
        #exit;
        if ( defined $vmInfo )
        {
            if ($getDataStore) {
                my $dsMoref = $vmInfo->{datastore};
                my $dsObj = Vim::get_view(mo_ref => @$dsMoref[0]);
                my $name = $dsObj->name;
                print "Datastore : $name";
                exit;
            }
            #print "vmInfo ::".Dumper($vmInfo)."\n";
            #print "VM MemorySizeMB :".$vmInfo->summary->config->memorySizeMB."\n";
            #print "VM CPU :".$vmInfo->summary->config->numCpu."\n";
            print "VM uuid :".$vmInfo->summary->config->uuid."\n";
            print "VM power State :".$vmInfo->runtime->powerState->val."\n";
            print "VM committed size :".$vmInfo->summary->storage->committed."\n";
            print "VM Total number of Ethernet Cards :".$vmInfo->summary->config->numEthernetCards."\n";
            my $size = ($vmInfo->summary->storage->committed + $vmInfo->summary->storage->uncommitted)/1024/1024/1024;
            print "VM Provisioned size :$size \n";

            my $EtherNetCards = $vmInfo->summary->config->numEthernetCards;

            #print "EtherNetCards=$EtherNetCards";


            my $devices =  $vmInfo->config->hardware->device;
            my $count = 0;

            if ($EtherNetCards >=0) {
                print "VMNicNetworkMapping=";
            }
            foreach my $device (@$devices) {
                my $mylabel = $device->deviceInfo->label;
                my $network = $device->deviceInfo->summary;
                #print "enthernet adapters:".$device->deviceInfo->label."\n";
                if ($mylabel =~ /Network adapter (\d+)/) {
                print "$1:$network|";
                #print "My Label:$1\n";
                $myArray[$count]=$1;

                $networkArray[$count]=$network;
                $count++;
                }
            }

            print "*\n";
            print "VMArray=@myArray\|";
           # foreach my $networkEle (@networkArray)
           # {
           # print "networkArray=$networkEle\|";
           # }
        }
        else
        {
            print "VM '$vmInfo' does not exists.\n";
        }
    };
    if ( $@)
    {
        print "Exception ..........\n".Dumper($@)."\n";
    }


}

