#!/bin/bash

if [ $# -lt 2 ]; then
    cat <<EOF
USAGE: process_node.sh [MODE] [FILE] (puppet args ...)

Executes the puppet asm process_node command against a deployment's
resource yaml file.

MODE should be either 'device' or 'apply' depending on the type of
resource being executed against. Currently storage resources should
use 'device' and all other swim lanes use 'apply'.

FILE should be a .yaml file from a deployment resources directory.

Additional arguments will be passed through to puppet. A useful
exmaple is "--debug"

EOF
    exit 1
fi

MODE="$1"
shift
FILE="$1"
shift

if [ "$MODE" != "apply" ] && [ "$MODE" != "device" ]; then
    cat <<EOF
USAGE: process_node.sh [MODE] [FILE] (puppet args ...)

MODE must be either 'apply' or 'device'

EOF
    exit 2
fi

if [ ! -f "$FILE" ]; then
    echo "Could not find file ${FILE}"
    exit 2
fi

BASENAME=`basename ${FILE}`
CERTNAME=`echo "${BASENAME}" | sed -e 's/\(___[0-9]\)*[.]yaml$//'`

# NOTE: using sudo to ensure correct path

sudo puppet asm process_node --filename $FILE --run_type $MODE --always-override $* $CERTNAME
