#!/bin/bash
REPO_STORE="/var/lib/razor/repo-store"

while getopts "d:" flag;
do
  case $flag in
    d) 
      DELETE_REPO='true'
      REPO_NAME="$OPTARG"
      ;;
  esac
done

if [ $DELETE_REPO ]
then
  razor delete-repo --name "${REPO_NAME}" 
  rm -fr "${REPO_STORE}/${REPO_NAME}"
  exit 0
else
  REPO_NAME="$1"
  TASK_NAME="$2"
  ISO_FILE="$3"
  REPODIR="${REPO_STORE}/${REPO_NAME}"

  if [ $# -ne 3 ]
    then
      echo "Proper usage is ./create-razor-repos.sh [REPO_NAME] [TASK_NAME] [ISO_FILE]" >&2
      exit 1
  fi


  if [ ! -f "$ISO_FILE" ]
  then
      echo "Could not find Image file at ${ISO_FILE}" >&2
      exit 2
  fi

  #Check existence of razor repo name.  If repo exists, don't create it.  We will still rsync the files later.
  razor repos "${REPO_NAME}" > /dev/null
  if [ $? -ne 0 ]; then
    # Create dummy repo
    razor create-repo --name "${REPO_NAME}" --iso-url "file:///dev/null" --task "${TASK_NAME}"
    if [ $? -ne 0 ]
      then
        echo "Failed to create the Razor repo ${REPO_NAME}" >&2
        exit 5
    fi
  fi

  # Copy ISO files into repo directory to work around issues with razor
  # unpacking the files
  MNT_DIR=`mktemp -d`

  mount -o loop "${ISO_FILE}" $MNT_DIR

  if [ $? -ne 0 ]
    then
      echo "Failed to mount ${ISO_FILE} at $MNT_DIR" >&2
      rm -fr $MNT_DIR
      exit 6
  fi

  #Necessary to perform rsync, as SELinux will prevent rsync from working correctly otherwise.
  semanage permissive -a rsync_t

  nice -n 19 ionice -c2 -n7 -t rsync -a $MNT_DIR/* "$REPODIR" --delete
  RSYNC_EXIT=$?
  if [ $RSYNC_EXIT != 0 ]
    then
      razor delete-repo --name "${REPO_NAME}"
  fi
  # Note: -d needed to free loop device
  umount -d $MNT_DIR
  rmdir $MNT_DIR
  rm -f $ISO_FILE
  rmdir `dirname $ISO_FILE`

  # Fix permissions of repo
  if [ $RSYNC_EXIT = 0 ]
    then
      chown -R root:root "${REPODIR}"
      find "${REPODIR}" -type d -exec chmod 755 {} ";"
      find "${REPODIR}" -type f -exec chmod 644 {} ";"
    else
      echo "Could not rsync iso to $REPODIR" >&2
      exit 7
  fi
fi
