#!/bin/bash
set -e
#Enable Debugging
set -x

if [ -d /etc/puppetlabs/puppet/devices ]; then
  rm -r /etc/puppetlabs/puppet/devices
fi

cp -r /var/tmp/restore/puppet/devices /etc/puppetlabs/puppet
chown -R pe-puppet:pe-puppet /etc/puppetlabs/puppet/devices

if [ "$(ls -A /etc/puppetlabs/puppet/devices 2> /dev/null)" == "" ]; then
  #Do Nothing as the directory is empty
  echo "/etc/puppetlabs/puppet/devices is empty!"
else
  chmod -f 664 /etc/puppetlabs/puppet/devices/*
fi
chmod 770 /etc/puppetlabs/puppet/devices


rm -r /etc/puppetlabs/puppet/manifests
cp -r /var/tmp/restore/puppet/manifests /etc/puppetlabs/puppet
chown -R root:pe-puppet /etc/puppetlabs/puppet/manifests

rm -r /var/lib/puppet
cp -r /var/tmp/restore/puppet/puppet /var/lib
chown -R pe-puppet:root /var/lib/puppet
chown root:root /var/lib/puppet

rm -rf /var/opt/lib/pe-puppet/devices
rm -rf /var/opt/lib/pe-puppet/reports
rm -rf /var/opt/lib/pe-puppet/yaml
rm -rf /var/opt/lib/pe-puppet/ssl

cd /var/opt/lib/pe-puppet
tar xfp /var/tmp/restore/puppet/pe-puppet.tar

# Delete puppet, puppetdb and puppet device ssl directories. The configureVM
# init script will regenerate new certs on start-up and and new device certs
# will be generated when they are executed during inventory or configuration.
rm -rf /var/opt/lib/pe-puppet/ssl
rm -rf /etc/puppetlabs/puppetdb/ssl
find /var/opt/lib/pe-puppet/devices -type d -name ssl -print0 | xargs -0 rm -rf

# -------  Restore Carbon Data ------------
# Some older backups may not have performance data, so we only copy if
# the carbon performance data exists.
if [ -d /var/opt/lib/pe-puppet/carbon ]; then
  # Remove the Existing Performance Metrics so files can be copied to it
  rm -rf /var/lib/carbon
  # Only Copy Over the Carbon Files AFTER the pe-puppet.tar is exploded
  cp -r /var/opt/lib/pe-puppet/carbon /var/lib/
  chown -R carbon:carbon /var/lib/carbon/
  chmod -R 755 /var/lib/carbon/
  if [ -d /var/lib/carbon/whisper/asm/poller/server ]; then
    chmod -f 644 /var/lib/carbon/whisper/asm/poller/server/*
  fi
  if [ -d /var/lib/carbon/whisper/carbon/agents/dellasm-a ]; then
    chmod -f 644 /var/lib/carbon/whisper/carbon/agents/dellasm-a/*
  fi
  if [ -d /var/lib/carbon/whisper/carbon/agents/dellasm-a/cache ]; then
    chmod -f 644 /var/lib/carbon/whisper/carbon/agents/dellasm-a/cache/*
  fi
  rm -r /var/opt/lib/pe-puppet/carbon
fi
# -------  End Restore Carbon Data ------------
# -------  Restore ntp client conf -----------
if [ -f /var/opt/lib/pe-puppet/ntp.conf ]; then
  rm /etc/ntp.conf
  cp /var/opt/lib/pe-puppet/ntp.conf /etc/ntp.conf
  chown root:root /etc/ntp.conf
  chmod 0644 /etc/ntp.conf
  rm /var/opt/lib/pe-puppet/ntp.conf
fi
if [ -f /var/opt/lib/pe-puppet/step-tickers ]; then
  if [ ! -d /etc/ntp ]; then
    mkdir /etc/ntp
  fi
  if [ -f /etc/ntp/step-tickers ]; then
    mv /etc/ntp/step-tickers /etc/ntp/step-tickers.bk
  fi
  cp /var/opt/lib/pe-puppet/step-tickers /etc/ntp/step-tickers
  chown root:root /etc/ntp/step-tickers
  chmod 0644 /etc/ntp/step-tickers
  rm /var/opt/lib/pe-puppet/step-tickers
  service ntpd restart
  chkconfig ntpd on
fi
# ------- End ntp restore ----------
# -------  Restore TimeZone -----------
if [ -f /var/opt/lib/pe-puppet/clock ]; then
  rm /etc/sysconfig/clock
  cp /var/opt/lib/pe-puppet/clock /etc/sysconfig/clock
  chown root:root /etc/sysconfig/clock
  chmod 0644 /etc/sysconfig/clock
  rm /var/opt/lib/pe-puppet/clock
fi
# ------- End TimeZone restore ----------
# ------- Always clear AddOn Modues -----
if [ -d /opt/Dell/ASM/modules ]; then
    rm -rf /opt/Dell/ASM/modules/*
fi
# ---------------------------------
# -------  Restore AddOn Modules -----------
if [ -d /var/opt/lib/pe-puppet/ASM/modules ]; then
  cp -r /var/opt/lib/pe-puppet/ASM/modules /opt/Dell/ASM/
  chown -R nobody:nobody /opt/Dell/ASM/modules
  chmod -R u=rwX,go=rX /opt/Dell/ASM/modules
  rm -rf /var/opt/lib/pe-puppet/ASM
fi
# ------- End AddOn Modules restore ----------

rm -rf /opt/Dell/ASM/deployments/*
cd /opt/Dell/ASM/deployments
if [ -f /var/tmp/restore/puppet/deployments.tar ]; then
  tar xfp /var/tmp/restore/puppet/deployments.tar

  if [ -d /opt/Dell/ASM/deployments/device ]; then
    cp -r /opt/Dell/ASM/deployments/device /opt/Dell/ASM/device
    rm -rf /opt/Dell/ASM/deployments/device
  fi
fi

rm -r /var/tmp/restore/puppet
